==> openshift_cli_installer-1.0.9.tar.gz: openshift_cli_installer-1.0.9/openshift_cli_installer/tests/test_cluster_version.py <==
import click
import pytest

from openshift_cli_installer.libs.aws_ipi_clusters import update_aws_clusters_versions
from openshift_cli_installer.libs.rosa_clusters import update_rosa_clusters_versions


@pytest.mark.parametrize(
    "clusters, expected",
    [
        (
            [{"version": "4.13", "stream": "stable", "platform": "aws"}],
            [
                {
                    "version": "4.13.9-x86_64",
                    "stream": "stable",
                    "platform": "aws",
                    "version_url": "quay.io/openshift-release-dev/ocp-release",
                }
            ],
        ),
        (
            [
                {"version": "4.13", "stream": "stable", "platform": "aws"},
                {"version": "4.13", "stream": "nightly", "platform": "aws"},
            ],
            [
                {
                    "version": "4.13.9-x86_64",
                    "stream": "stable",
                    "platform": "aws",
                    "version_url": "quay.io/openshift-release-dev/ocp-release",
                },
                {
                    "version": "4.13.0-0.nightly-2023-08-15-023315",
                    "stream": "nightly",
                    "platform": "aws",
                    "version_url": "registry.ci.openshift.org/ocp/release",
                },
            ],
        ),
        (
            [{"version": "4.13", "stream": "nightly", "platform": "aws"}],
            [
                {
                    "version": "4.13.0-0.nightly-2023-08-15-023315",
                    "stream": "nightly",
                    "platform": "aws",
                    "version_url": "registry.ci.openshift.org/ocp/release",
                }
            ],
        ),
        (
            [{"version": "4.13", "stream": "ec", "platform": "aws"}],
            [
                {
                    "version": "4.13.0-ec.4-x86_64",
                    "stream": "ec",
                    "platform": "aws",
                    "version_url": "quay.io/openshift-release-dev/ocp-release",
                }
            ],
        ),
        (
            [{"version": "4.13", "stream": "rc", "platform": "aws"}],
            [
                {
                    "version": "4.13.0-rc.8-x86_64",
                    "stream": "rc",
                    "platform": "aws",
                    "version_url": "quay.io/openshift-release-dev/ocp-release",
                }
            ],
        ),
        (
            [{"version": "4.13", "stream": "ci", "platform": "aws"}],
            [
                {
                    "version": "4.13.0-0.ci-2023-08-14-170508",
                    "stream": "ci",
                    "platform": "aws",
                    "version_url": "registry.ci.openshift.org/ocp/release",
                }
            ],
        ),
        (
            [{"version": "4.13.9", "stream": "stable", "platform": "aws"}],
            [
                {
                    "version": "4.13.9-x86_64",
                    "stream": "stable",
                    "platform": "aws",
                    "version_url": "quay.io/openshift-release-dev/ocp-release",
                }
            ],
        ),
        ([{"version": "4", "stream": "stable", "platform": "aws"}], "error"),
        ([{"version": "100.5.1", "stream": "stable", "platform": "aws"}], "error"),
        ([{"version": "100.5", "stream": "stable", "platform": "aws"}], "error"),
        ([{"version": "4.13.40", "stream": "stable", "platform": "aws"}], "error"),
    ],
    ids=[
        "aws_4.13_stable",
        "aws_4.13_stable_and_nightly",
        "aws_4.13_nightly",
        "aws_4.13_ec",
        "aws_4.13_rc",
        "aws_4.13_ci",
        "aws_4.13.9_stable",
        "aws_4_stable_negative",
        "aws_100.5.1_stable_negative",
        "aws_100.5_stable_negative",
        "aws_4.13.40_stable_negative",
    ],
)
def test_aws_cluster_version(clusters, expected):
    try:
        res = update_aws_clusters_versions(clusters=clusters, _test=True)
        assert res == expected
    except click.Abort:
        if expected == "error":
            return
        else:
            raise


@pytest.mark.parametrize(
    "clusters, expected",
    [
        (
            [
                {
                    "version": "4.13",
                    "channel-group": "stable",
                    "platform": "rosa",
                }
            ],
            [
                {
                    "version": "4.13.6",
                    "channel-group": "stable",
                    "platform": "rosa",
                }
            ],
        ),
        (
            [
                {
                    "version": "4.13",
                    "channel-group": "nightly",
                    "platform": "rosa",
                }
            ],
            [
                {
                    "version": "4.13.0-0.nightly-2023-08-15-023315",
                    "channel-group": "nightly",
                    "platform": "rosa",
                }
            ],
        ),
        (
            [
                {
                    "version": "4.13",
                    "channel-group": "candidate",
                    "platform": "rosa",
                }
            ],
            [
                {
                    "version": "4.13.9",
                    "channel-group": "candidate",
                    "platform": "rosa",
                }
            ],
        ),
        (
            [
                {
                    "version": "4.13.6",
                    "channel-group": "stable",
                    "platform": "rosa",
                }
            ],
            [
                {
                    "version": "4.13.6",
                    "channel-group": "stable",
                    "platform": "rosa",
                }
            ],
        ),
        (
            [
                {
                    "version": "4.13",
                    "channel-group": "stable",
                    "platform": "rosa",
                },
                {
                    "version": "4.13",
                    "channel-group": "nightly",
                    "platform": "rosa",
                },
            ],
            [
                {
                    "version": "4.13.6",
                    "channel-group": "stable",
                    "platform": "rosa",
                },
                {
                    "version": "4.13.0-0.nightly-2023-08-15-023315",
                    "channel-group": "nightly",
                    "platform": "rosa",
                },
            ],
        ),
        (
            [
                {
                    "version": "4",
                    "channel-group": "stable",
                    "platform": "rosa",
                }
            ],
            "error",
        ),
        (
            [
                {
                    "version": "100.5.1",
                    "channel-group": "stable",
                    "platform": "rosa",
                }
            ],
            "error",
        ),
        (
            [
                {
                    "version": "100.5",
                    "channel-group": "stable",
                    "platform": "rosa",
                }
            ],
            "error",
        ),
        (
            [
                {
                    "version": "4.13.40",
                    "channel-group": "stable",
                    "platform": "rosa",
                }
            ],
            "error",
        ),
    ],
    ids=[
        "rosa_4.13_stable",
        "rosa_4.13_nightly",
        "rosa_4.13_candidate",
        "rosa_4.13.6_stable",
        "rosa_4.13_stable_and_nightly",
        "rosa_4_stable_negative",
        "rosa_100.5.1_stable_negative",
        "rosa_100.5_stable_negative",
        "rosa_4.13.40_stable_negative",
    ],
)
def test_rosa_cluster_version(clusters, expected):
    try:
        res = update_rosa_clusters_versions(
            clusters=clusters, _test=True, ocm_env=None, ocm_token=None
        )
        assert res == expected
    except click.Abort:
        if expected == "error":
            return
        else:
            raise

==> openshift_cli_installer-1.0.16.tar.gz: openshift_cli_installer-1.0.16/openshift_cli_installer/tests/test_cluster_version.py <==
import click
import pytest

from openshift_cli_installer.libs.aws_ipi_clusters import update_aws_clusters_versions
from openshift_cli_installer.utils.helpers import update_rosa_osd_clusters_versions


@pytest.mark.parametrize(
    "clusters, expected",
    [
        (
            [{"version": "4.13", "stream": "stable", "platform": "aws"}],
            [
                {
                    "version": "4.13.9-x86_64",
                    "stream": "stable",
                    "platform": "aws",
                    "version_url": "quay.io/openshift-release-dev/ocp-release",
                }
            ],
        ),
        (
            [
                {"version": "4.13", "stream": "stable", "platform": "aws"},
                {"version": "4.13", "stream": "nightly", "platform": "aws"},
            ],
            [
                {
                    "version": "4.13.9-x86_64",
                    "stream": "stable",
                    "platform": "aws",
                    "version_url": "quay.io/openshift-release-dev/ocp-release",
                },
                {
                    "version": "4.13.0-0.nightly-2023-08-15-023315",
                    "stream": "nightly",
                    "platform": "aws",
                    "version_url": "registry.ci.openshift.org/ocp/release",
                },
            ],
        ),
        (
            [{"version": "4.13", "stream": "nightly", "platform": "aws"}],
            [
                {
                    "version": "4.13.0-0.nightly-2023-08-15-023315",
                    "stream": "nightly",
                    "platform": "aws",
                    "version_url": "registry.ci.openshift.org/ocp/release",
                }
            ],
        ),
        (
            [{"version": "4.13", "stream": "ec", "platform": "aws"}],
            [
                {
                    "version": "4.13.0-ec.4-x86_64",
                    "stream": "ec",
                    "platform": "aws",
                    "version_url": "quay.io/openshift-release-dev/ocp-release",
                }
            ],
        ),
        (
            [{"version": "4.13", "stream": "rc", "platform": "aws"}],
            [
                {
                    "version": "4.13.0-rc.8-x86_64",
                    "stream": "rc",
                    "platform": "aws",
                    "version_url": "quay.io/openshift-release-dev/ocp-release",
                }
            ],
        ),
        (
            [{"version": "4.13", "stream": "ci", "platform": "aws"}],
            [
                {
                    "version": "4.13.0-0.ci-2023-08-14-170508",
                    "stream": "ci",
                    "platform": "aws",
                    "version_url": "registry.ci.openshift.org/ocp/release",
                }
            ],
        ),
        (
            [{"version": "4.13.9", "stream": "stable", "platform": "aws"}],
            [
                {
                    "version": "4.13.9-x86_64",
                    "stream": "stable",
                    "platform": "aws",
                    "version_url": "quay.io/openshift-release-dev/ocp-release",
                }
            ],
        ),
        ([{"version": "4", "stream": "stable", "platform": "aws"}], "error"),
        ([{"version": "100.5.1", "stream": "stable", "platform": "aws"}], "error"),
        ([{"version": "100.5", "stream": "stable", "platform": "aws"}], "error"),
        ([{"version": "4.13.40", "stream": "stable", "platform": "aws"}], "error"),
    ],
    ids=[
        "aws_4.13_stable",
        "aws_4.13_stable_and_nightly",
        "aws_4.13_nightly",
        "aws_4.13_ec",
        "aws_4.13_rc",
        "aws_4.13_ci",
        "aws_4.13.9_stable",
        "aws_4_stable_negative",
        "aws_100.5.1_stable_negative",
        "aws_100.5_stable_negative",
        "aws_4.13.40_stable_negative",
    ],
)
def test_aws_cluster_version(clusters, expected):
    try:
        res = update_aws_clusters_versions(clusters=clusters, _test=True)
        assert res == expected
    except click.Abort:
        if expected == "error":
            return
        else:
            raise


@pytest.mark.parametrize(
    "clusters, expected",
    [
        (
            [
                {
                    "version": "4.13",
                    "channel-group": "stable",
                    "platform": "rosa",
                }
            ],
            [
                {
                    "version": "4.13.6",
                    "channel-group": "stable",
                    "platform": "rosa",
                }
            ],
        ),
        (
            [
                {
                    "version": "4.13",
                    "channel-group": "nightly",
                    "platform": "rosa",
                }
            ],
            [
                {
                    "version": "4.13.0-0.nightly-2023-08-15-023315",
                    "channel-group": "nightly",
                    "platform": "rosa",
                }
            ],
        ),
        (
            [
                {
                    "version": "4.13",
                    "channel-group": "candidate",
                    "platform": "rosa",
                }
            ],
            [
                {
                    "version": "4.13.9",
                    "channel-group": "candidate",
                    "platform": "rosa",
                }
            ],
        ),
        (
            [
                {
                    "version": "4.13.6",
                    "channel-group": "stable",
                    "platform": "rosa",
                }
            ],
            [
                {
                    "version": "4.13.6",
                    "channel-group": "stable",
                    "platform": "rosa",
                }
            ],
        ),
        (
            [
                {
                    "version": "4.13",
                    "channel-group": "stable",
                    "platform": "rosa",
                },
                {
                    "version": "4.13",
                    "channel-group": "nightly",
                    "platform": "rosa",
                },
            ],
            [
                {
                    "version": "4.13.6",
                    "channel-group": "stable",
                    "platform": "rosa",
                },
                {
                    "version": "4.13.0-0.nightly-2023-08-15-023315",
                    "channel-group": "nightly",
                    "platform": "rosa",
                },
            ],
        ),
        (
            [
                {
                    "version": "4",
                    "channel-group": "stable",
                    "platform": "rosa",
                }
            ],
            "error",
        ),
        (
            [
                {
                    "version": "100.5.1",
                    "channel-group": "stable",
                    "platform": "rosa",
                }
            ],
            "error",
        ),
        (
            [
                {
                    "version": "100.5",
                    "channel-group": "stable",
                    "platform": "rosa",
                }
            ],
            "error",
        ),
        (
            [
                {
                    "version": "4.13.40",
                    "channel-group": "stable",
                    "platform": "rosa",
                }
            ],
            "error",
        ),
    ],
    ids=[
        "rosa_4.13_stable",
        "rosa_4.13_nightly",
        "rosa_4.13_candidate",
        "rosa_4.13.6_stable",
        "rosa_4.13_stable_and_nightly",
        "rosa_4_stable_negative",
        "rosa_100.5.1_stable_negative",
        "rosa_100.5_stable_negative",
        "rosa_4.13.40_stable_negative",
    ],
)
def test_rosa_cluster_version(clusters, expected):
    try:
        res = update_rosa_osd_clusters_versions(
            clusters=clusters, _test=True, ocm_env=None, ocm_token=None
        )
        assert res == expected
    except click.Abort:
        if expected == "error":
            return
        else:
            raise
